==> pystan-0.2.1.tar.gz: pystan-0.2.1/pystan/stan/src/stan/math/matrix/cumulative_sum.hpp <==
#ifndef __STAN__MATH__MATRIX__CUMULATIVE_SUM_HPP__
#define __STAN__MATH__MATRIX__CUMULATIVE_SUM_HPP__

#include <vector>
#include <stan/math/matrix/Eigen.hpp>

namespace stan {
  namespace math {

    /**
     * Return the cumulative sum of the specified vector.
     *
     * The cumulative sum of a vector of values \code{x} is the
     *
     * <code>x[0], x[1] + x[2], ..., x[1] + ,..., + x[x.size()-1]</code>
     *
     * @tparm T Scalar type of vector.
     * @param x Vector of values.
     * @return Cumulative sum of values.
     */
    template <typename T>
    inline std::vector<T>
    cumulative_sum(const std::vector<T>& x) {
      std::vector<T> result(x.size());
      if (x.size() == 0)
        return result;
      result[0] = x[0];
      for (size_t i = 1; i < result.size(); ++i)
        result[i] = x[i] + result[i-1];
      return result;
    }
    
    /**
     * Return the cumulative sum of the specified matrix.
     *
     * The cumulative sum is of the same type as the input and
     * has values defined by
     *
     * <code>x(0), x(1) + x(2), ..., x(1) + ,..., + x(x.size()-1)</code>
     *
     * @tparm T Scalar type of matrix.
     * @tparam R Row type of matrix.
     * @tparam C Column type of matrix.
     * @param x Vector of values.
     * @return Cumulative sum of values.
     */
    template <typename T, int R, int C>
    inline Eigen::Matrix<T,R,C> 
    cumulative_sum(const Eigen::Matrix<T,R,C>& m) {
      Eigen::Matrix<T,R,C> result(m.rows(),m.cols());
      if (m.size() == 0)
        return result;
      result(0) = m(0);
      for (int i = 1; i < result.size(); ++i)
        result(i) = m(i) + result(i-1);
      return result;
    }
  }
}
#endif

==> pystan-2.3.0.0.tar.gz: pystan-2.3.0.0/pystan/stan/src/stan/math/matrix/cumulative_sum.hpp <==
#ifndef __STAN__MATH__MATRIX__CUMULATIVE_SUM_HPP__
#define __STAN__MATH__MATRIX__CUMULATIVE_SUM_HPP__

#include <vector>
#include <stan/math/matrix/Eigen.hpp>

namespace stan {
  namespace math {

    /**
     * Return the cumulative sum of the specified vector.
     *
     * The cumulative sum of a vector of values \code{x} is the
     *
     * @code x[0], x[1] + x[2], ..., x[1] + ,..., + x[x.size()-1] @endcode
     *
     * @tparam T Scalar type of vector.
     * @param x Vector of values.
     * @return Cumulative sum of values.
     */
    template <typename T>
    inline std::vector<T>
    cumulative_sum(const std::vector<T>& x) {
      std::vector<T> result(x.size());
      if (x.size() == 0)
        return result;
      result[0] = x[0];
      for (size_t i = 1; i < result.size(); ++i)
        result[i] = x[i] + result[i-1];
      return result;
    }
    
    /**
     * Return the cumulative sum of the specified matrix.
     *
     * The cumulative sum is of the same type as the input and
     * has values defined by
     *
     * @code x(0), x(1) + x(2), ..., x(1) + ,..., + x(x.size()-1) @endcode
     *
     * @tparam T Scalar type of matrix.
     * @tparam R Row type of matrix.
     * @tparam C Column type of matrix.
     * @param m Matrix of values. 
     * @return Cumulative sum of values.
     */
    template <typename T, int R, int C>
    inline Eigen::Matrix<T,R,C> 
    cumulative_sum(const Eigen::Matrix<T,R,C>& m) {
      Eigen::Matrix<T,R,C> result(m.rows(),m.cols());
      if (m.size() == 0)
        return result;
      result(0) = m(0);
      for (int i = 1; i < result.size(); ++i)
        result(i) = m(i) + result(i-1);
      return result;
    }
  }
}
#endif
